==> auto-ui-2.4.55.tgz: package/es/dialog/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { createPortal } from 'react-dom';
import IconClose from '../icon/close_s';
import Modal from '../modal/index';
import './style/index.scss';
var Dialog = /** @class */ (function (_super) {
    __extends(Dialog, _super);
    function Dialog(props) {
        var _this = _super.call(this, props) || this;
        _this.div = void 0;
        _this.div = document.createElement('div');
        _this.div.classList.add('_x_dialog_');
        document.body.appendChild(_this.div);
        return _this;
    }
    Dialog.prototype.componentWillUnmount = function () {
        if (this.div) {
            document.body.removeChild(this.div);
        }
    };
    Dialog.prototype.content = function () {
        var _a = this.props, className = _a.className, height = _a.height, visible = _a.visible, title = _a.title, _b = _a.keepalive, keepalive = _b === void 0 ? true : _b, children = _a.children, onMaskClick = _a.onMaskClick, onCloseClick = _a.onCloseClick, otherProps = __rest(_a, ["className", "height", "visible", "title", "keepalive", "children", "onMaskClick", "onCloseClick"]);
        var composeClassName = cn('x-dialog', {
            'x-dialog--fix-top': !!onCloseClick && !title,
        }, className);
        return (React.createElement(Modal, __assign({}, otherProps, { visible: visible, keepalive: keepalive, height: height, onMaskClick: onMaskClick, className: composeClassName }),
            onCloseClick && (React.createElement("button", { className: "x-dialog__close", onClick: onCloseClick },
                React.createElement(IconClose, null))),
            title && React.createElement("h1", { className: "x-dialog__title" }, title),
            React.createElement("div", { className: "x-dialog__inner" }, children)));
    };
    Dialog.prototype.render = function () {
        return this.div && createPortal(this.content(), this.div);
    };
    return Dialog;
}(React.Component));
var Scroller = function (props) {
    var className = props.className, children = props.children, otherProps = __rest(props, ["className", "children"]);
    var composeClassName = cn('x-dialog__scroller', className);
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        React.createElement("div", { className: "x-dialog__inscroller" }, children)));
};
Dialog.Scroller = Scroller;
export default Dialog;

==> auto-ui-2.4.63.tgz: package/es/dialog/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { createPortal } from 'react-dom';
import IconClose from '../icon/close_s';
import Modal from '../modal/index';
import './style/index.scss';
var Dialog = /** @class */ (function (_super) {
    __extends(Dialog, _super);
    function Dialog(props) {
        var _this = _super.call(this, props) || this;
        _this.div = void 0;
        _this.div = document.createElement('div');
        _this.div.classList.add('_x_dialog_');
        document.body.appendChild(_this.div);
        return _this;
    }
    Dialog.prototype.componentWillUnmount = function () {
        if (this.div) {
            document.body.removeChild(this.div);
        }
    };
    Dialog.prototype.content = function () {
        var _a = this.props, className = _a.className, height = _a.height, visible = _a.visible, title = _a.title, _b = _a.keepalive, keepalive = _b === void 0 ? true : _b, children = _a.children, onMaskClick = _a.onMaskClick, onCloseClick = _a.onCloseClick, otherProps = __rest(_a, ["className", "height", "visible", "title", "keepalive", "children", "onMaskClick", "onCloseClick"]);
        var composeClassName = cn('x-dialog', {
            'x-dialog--fix-top': !!onCloseClick && !title,
        }, className);
        return (React.createElement(Modal, __assign({}, otherProps, { visible: visible, keepalive: keepalive, height: height, onMaskClick: onMaskClick, className: composeClassName }),
            onCloseClick && (React.createElement("button", { className: "x-dialog__close", onClick: onCloseClick },
                React.createElement(IconClose, null))),
            title && React.createElement("h1", { className: "x-dialog__title" }, title),
            React.createElement("div", { className: "x-dialog__inner" }, children)));
    };
    Dialog.prototype.render = function () {
        return this.div && createPortal(this.content(), this.div);
    };
    return Dialog;
}(React.Component));
var Scroller = function (props) {
    var className = props.className, children = props.children, otherProps = __rest(props, ["className", "children"]);
    var composeClassName = cn('x-dialog__scroller', className);
    return (React.createElement("div", __assign({}, otherProps, { className: composeClassName }),
        React.createElement("div", { className: "x-dialog__inscroller" }, children)));
};
Dialog.Scroller = Scroller;
export default Dialog;
